# Spark-NLP
John Snow Labs Spark NLP is a natural language processing library built on top of Apache Spark ML. It provides simple, performant & accurate NLP annotations for machine learning pipelines, that scale easily in a distributed environment.

## Requirements
Spark NLP is built on top of Apache Spark 2.4.0 and works with any user provided Spark 2.x.x it is advised to have basic knowledge of the framework and a working environment before using Spark NLP.

# Spark-NLP for Python

Dependencies on `python3-devel` and `wheel` python module

Build python package with `python3 setup.py sdist bdist_wheel`

Install with `python3 -m pip install --force-reinstall --user dist/spark_nlp-2.2.2-py2.py3-none-any.whl`
